#!/bin/bash

set -e
set -u

git remote update emacs
git checkout upstream

changes=$(git rev-list --count upstream..emacs/master 2>/dev/null)
if [[ ${changes} -lt 1 ]]; then
    echo "No updates to upstream, not building"
#    exit 0
fi

git fetch emacs
git reset --hard
git clean -ffdx

git checkout upstream
git merge -m 'Merged upstream' emacs/master

git checkout master
git merge -m 'Merging new upstream' -s recursive -X theirs upstream

gbp pq rebase
gbp pq export

GITCOMMITID=$(git rev-parse emacs/master)
test -n "${GITCOMMITID}"

sed -i -e "s/emacs.ganneff.de.*$/emacs.ganneff.de\/, git commit ${GITCOMMITID}\"/" debian/patches/0005-Modify-the-output-of-version-to-indicate-Debian-modi.patch

git add -vf debian/patches/ || true

# I let this fail because no patch updates may be necessary
git commit --no-verify -m 'patch update' debian/patches/ || true

# need to make this non-interactive
UPSTREAM_VER=$(git describe --tags --always emacs/master)
test -n "$UPSTREAM_VER" # make sure version was parsed
# Write out/Update patch to have git commitid in M-x emacs-version
export DEBEMAIL=joerg@debian.org
export DEBFULLNAME='Joerg Jaspert'
dch -v `date +'2:%Y%m%d+'$UPSTREAM_VER'-1'` 'New snapshot'
dch -r ''
git commit -m 'new snapshot' debian/changelog

# done preparing the source. Push and build
git push origin upstream:upstream
git push origin master:master
git push -f origin patch-queue/master:patch-queue/master
